@@ -6,14 +6,14 @@
 
 
 ## Fit a 'simple' 2D RK model:
-setMethod("fit.gstatModel", signature(observations = "SpatialPointsDataFrame", formulaString = "formula", covariates = "SpatialPixelsDataFrame"), function(observations, formulaString, covariates, method = list("GLM", "rpart", "randomForest", "quantregForest")[[1]], dimensions = list("3D", "2D", "2D+T", "3D+T")[[1]], family = gaussian(), stepwise = TRUE, vgmFun = "Exp", subsample = 5000, ...){
+setMethod("fit.gstatModel", signature(observations = "SpatialPointsDataFrame", formulaString = "formula", covariates = "SpatialPixelsDataFrame"), function(observations, formulaString, covariates, method = list("GLM", "rpart", "randomForest", "quantregForest")[[1]], dimensions = list("3D", "2D", "2D+T", "3D+T")[[1]], fit.family = gaussian(), stepwise = TRUE, vgmFun = "Exp", subsample = 5000, ...){
  
   ## TH: the function only works with 2D maps at the moment:
   if(length(attr(coordinates(observations), "dimnames")[[2]])>2){
     warning("This method uses only 2D coordinates of the points. For 3D data consider using the 'geosamples-class'.")
   }
 
-  if(!missing(family) & !method=="GLM"){ warning("'family' argument will be ignored. Use 'method=\"GLM\"' instead.")  }
+  if(!missing(fit.family) & !method=="GLM"){ warning("'fit.family' argument will be ignored. Use 'method=\"GLM\"' instead.")  }
 
   ## overlay:
   ov <- over(observations, covariates)
@@ -40,7 +40,7 @@ setMethod("fit.gstatModel", signature(observations = "SpatialPointsDataFrame", f
   }
   
   # fit/filter the regression model:
-  m <- fit.regModel(formulaString = formulaString, rmatrix = ov, predictionDomain = covariates[seln], method = method, dimensions = "2D", family = family, stepwise = stepwise, vgmFun = vgmFun, subsample = subsample, ...)  
+  m <- fit.regModel(formulaString = formulaString, rmatrix = ov, predictionDomain = covariates[seln], method = method, dimensions = "2D", fit.family = fit.family, stepwise = stepwise, vgmFun = vgmFun, subsample = subsample, ...)  
     
   return(m)
   
@@ -48,7 +48,7 @@ setMethod("fit.gstatModel", signature(observations = "SpatialPointsDataFrame", f
 
 
 ## Fit a RK model using geosamples class:
-setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString = "formula", covariates = "SpatialPixelsDataFrame"), function(observations, formulaString, covariates, method = list("GLM", "rpart", "randomForest", "quantregForest")[[1]], dimensions = list("3D", "2D", "2D+T", "3D+T")[[1]], family = gaussian(), stepwise = TRUE, vgmFun = "Exp", subsample = 5000, ...){
+setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString = "formula", covariates = "SpatialPixelsDataFrame"), function(observations, formulaString, covariates, method = list("GLM", "rpart", "randomForest", "quantregForest")[[1]], dimensions = list("3D", "2D", "2D+T", "3D+T")[[1]], fit.family = gaussian(), stepwise = TRUE, vgmFun = "Exp", subsample = 5000, ...){
   
   ## all columns of interest:
   methodid = all.vars(formulaString)[1]
@@ -69,7 +69,7 @@ setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString
   if(dimensions == "2D"){ ov <- ov[, c(methodid, names(covariates)[seln], xyn)] }
   
   ## fit/filter the regression model:
-  m <- fit.regModel(formulaString = formulaString, rmatrix = ov, predictionDomain = covariates[seln], method = method, dimensions = dimensions, family = family, stepwise = stepwise, vgmFun = vgmFun, subsample = subsample, ...)
+  m <- fit.regModel(formulaString = formulaString, rmatrix = ov, predictionDomain = covariates[seln], method = method, dimensions = dimensions, fit.family = fit.family, stepwise = stepwise, vgmFun = vgmFun, subsample = subsample, ...)
   
   return(m)  
 
@@ -77,14 +77,14 @@ setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString
 
 
 ## Fit a RK model to a list of covariates / formulas:
-setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString = "list", covariates = "list"), function(observations, formulaString, covariates, method = list("GLM", "rpart", "randomForest", "quantregForest")[[1]], dimensions = list("3D", "2D", "2D+T", "3D+T")[[1]], family = gaussian(), stepwise = TRUE, vgmFun = "Exp", subsample = 5000, ...){
+setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString = "list", covariates = "list"), function(observations, formulaString, covariates, method = list("GLM", "rpart", "randomForest", "quantregForest")[[1]], dimensions = list("3D", "2D", "2D+T", "3D+T")[[1]], fit.family = gaussian(), stepwise = TRUE, vgmFun = "Exp", subsample = 5000, ...){
     if(!length(formulaString)==length(covariates)){
       stop("'formulaString' and 'covariates' lists of same size expected")
     }
     
     rkm.l <- list(NULL)
     for(l in 1:length(covariates)){   
-      rkm.l[[l]] <- fit.gstatModel(observations, formulaString[[l]], covariates[[l]], methodid = methodid, family = family, stepwise = stepwise, subsample = subsample, ...)
+      rkm.l[[l]] <- fit.gstatModel(observations, formulaString[[l]], covariates[[l]], methodid = methodid, fit.family = fit.family, stepwise = stepwise, subsample = subsample, ...)
     }
     return(rkm.l)  
 
@@ -92,14 +92,14 @@ setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString
 
 
 ## Fit a RK model and return an object of class "gstatModel" for a list of multiscale grids:
-setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString = "formula", covariates = "list"), function(observations, formulaString, covariates, method = list("GLM", "rpart", "randomForest", "quantregForest")[[1]], dimensions = list("3D", "2D", "2D+T", "3D+T")[[1]], family = gaussian(), stepwise = TRUE, vgmFun = "Exp", subsample = 5000, ...){
+setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString = "formula", covariates = "list"), function(observations, formulaString, covariates, method = list("GLM", "rpart", "randomForest", "quantregForest")[[1]], dimensions = list("3D", "2D", "2D+T", "3D+T")[[1]], fit.family = gaussian(), stepwise = TRUE, vgmFun = "Exp", subsample = 5000, ...){
 
   if(!any(sapply(covariates, class)=="SpatialPixelsDataFrame")){
     stop("List of covariates of class 'SpatialPixelsDataFrame' expected")
   }
 
-  if(!missing(family) & !method=="GLM"){ 
-    warning("'family' argument will be ignored. Use 'method=\"GLM\"' instead.")  
+  if(!missing(fit.family) & !method=="GLM"){ 
+    warning("'fit.family' argument will be ignored. Use 'method=\"GLM\"' instead.")  
   }
 
   # covariate names:
@@ -137,7 +137,7 @@ setMethod("fit.gstatModel", signature(observations = "geosamples", formulaString
   }
   
   # fit/filter the regression model:
-  m <- fit.regModel(formulaString = formulaString, rmatrix = ov, predictionDomain = covariates[[1]], method = method, dimensions = "3D", family = family, stepwise = stepwise, vgmFun = vgmFun, subsample = subsample, ...)
+  m <- fit.regModel(formulaString = formulaString, rmatrix = ov, predictionDomain = covariates[[1]], method = method, dimensions = "3D", fit.family = fit.family, stepwise = stepwise, vgmFun = vgmFun, subsample = subsample, ...)
   
   # save the fitted model:
   return(m) 
